# Installation

Currently you need to clone VirtualiZarr and install it locally:

```shell
git clone https://github.com/zarr-developers/VirtualiZarr
cd VirtualiZarr
pip install -e .
```


## Install Test Dependencies

```shell
pip install '-e .[test]'
```


## Install Docs Dependencies

```shell
pip install '-e .[docs]'
```
